  {% extends "admin/base.html" %} {% load static %} {% block extrahead %}
  <link
    rel="stylesheet"
    type="text/css"
    href="{% static 'css/custom_admin.css' %}"
  />
  {% endblock %} {% block content %}
  <div class="custom-base-content">{{ block.super }}</div>
  {% endblock %}
